@@ -22,6 +22,8 @@
 #'  by pooling the data for all of the classes?
 #' @param log A logical: should the distances be transformed by
 #'  the natural log function?
+#' @param prefix A character string that defines the naming convention for
+#'  new distance columns. Defaults to `"classdist_"`. See Details below.
 #' @param objects Statistics are stored here once this step has
 #'  been trained by [prep.recipe()].
 #' @return An updated version of `recipe` with the new step
@@ -36,7 +38,8 @@
 #' @details `step_classdist` will create a new column for every
 #'  unique value of the `class` variable.
 #'  The resulting variables will not replace the original values
-#'  and have the prefix `classdist_`.
+#'  and by default have the prefix `classdist_`. The naming format can be
+#'  changed using the `prefix` argument.
 #'
 #' Note that, by default, the default covariance function requires
 #'  that each class should have at least as many rows as variables
@@ -48,6 +51,12 @@
 #' # in case of missing data...
 #' mean2 <- function(x) mean(x, na.rm = TRUE)
 #'
+#' # define naming convention
+#' rec <- recipe(Species ~ ., data = iris) %>%
+#'   step_classdist(all_predictors(), class = "Species",
+#'                  pool = FALSE, mean_func = mean2, prefix = "centroid_")
+#'
+#' # default naming
 #' rec <- recipe(Species ~ ., data = iris) %>%
 #'   step_classdist(all_predictors(), class = "Species",
 #'                  pool = FALSE, mean_func = mean2)
@@ -61,7 +70,6 @@
 #'
 #' tidy(rec, number = 1)
 #' tidy(rec_dists, number = 1)
-#' @importFrom stats cov
 step_classdist <- function(recipe,
                            ...,
                            class,
@@ -72,10 +80,11 @@ step_classdist <- function(recipe,
                            pool = FALSE,
                            log = TRUE,
                            objects = NULL,
+                           prefix = "classdist_",
                            skip = FALSE,
                            id = rand_id("classdist")) {
   if (!is.character(class) || length(class) != 1)
-    stop("`class` should be a single character value.")
+    rlang::abort("`class` should be a single character value.")
   add_step(
     recipe,
     step_classdist_new(
@@ -88,6 +97,7 @@ step_classdist <- function(recipe,
       pool = pool,
       log = log,
       objects = objects,
+      prefix = prefix,
       skip = skip,
       id = id
     )
@@ -96,7 +106,7 @@ step_classdist <- function(recipe,
 
 step_classdist_new <-
   function(terms, class, role, trained, mean_func,
-           cov_func, pool, log, objects, skip, id) {
+           cov_func, pool, log, objects, prefix, skip, id) {
     step(
       subclass = "classdist",
       terms = terms,
@@ -108,6 +118,7 @@ step_classdist_new <-
       pool = pool,
       log = log,
       objects = objects,
+      prefix = prefix,
       skip = skip,
       id = id
     )
@@ -121,8 +132,6 @@ get_both <- function(x, mfun = mean, cfun = cov) {
        scale = cfun(x))
 }
 
-
-#' @importFrom stats as.formula model.frame
 #' @export
 prep.step_classdist <- function(x, training, info = NULL, ...) {
   class_var <- x$class[1]
@@ -154,13 +163,12 @@ prep.step_classdist <- function(x, training, info = NULL, ...) {
     pool = x$pool,
     log = x$log,
     objects = res,
+    prefix = x$prefix,
     skip = x$skip,
     id = x$id
   )
 }
 
-
-#' @importFrom stats mahalanobis
 mah_by_class <- function(param, x)
   mahalanobis(x, param$center, param$scale)
 
@@ -168,7 +176,6 @@ mah_pooled <- function(means, x, cov_mat)
   mahalanobis(x, means, cov_mat)
 
 
-#' @importFrom tibble as_tibble
 #' @export
 bake.step_classdist <- function(object, new_data, ...) {
   if (object$pool) {
@@ -187,7 +194,7 @@ bake.step_classdist <- function(object, new_data, ...) {
   if (object$log)
     res <- lapply(res, log)
   res <- as_tibble(res)
-  newname <- paste0("classdist_", colnames(res))
+  newname <- paste0(object$prefix, colnames(res))
   res <- check_name(res, new_data, object, newname)
   res <- bind_cols(new_data, res)
   if (!is_tibble(res))
@@ -217,7 +224,6 @@ get_centroid <- function(x) {
 
 #' @rdname step_classdist
 #' @param x A `step_classdist` object.
-#' @importFrom dplyr bind_rows
 #' @export
 tidy.step_classdist <- function(x, ...) {
   if (is_trained(x)) {
