@@ -108,7 +108,7 @@ step_ica <-
            id = rand_id("ica")) {
 
 
-    recipes_pkg_check(c("dimRed", "fastICA"))
+    recipes_pkg_check(required_pkgs.step_ica())
 
     add_step(
       recipe,
@@ -257,3 +257,10 @@ tunable.step_ica <- function(x, ...) {
     component_id = x$id
   )
 }
+
+
+#' @rdname required_pkgs.step
+#' @export
+required_pkgs.step_ica <- function(x, ...) {
+  c("dimRed", "fastICA")
+}
