@@ -40,7 +40,7 @@
 #' @concept basis_expansion
 #' @export
 #' @details Kernel principal component analysis (kPCA) is an
-#'  extension a PCA analysis that conducts the calculations in a
+#'  extension of a PCA analysis that conducts the calculations in a
 #'  broader dimensionality defined by a kernel function. For
 #'  example, if a quadratic kernel function were used, each variable
 #'  would be represented by its original values as well as its
@@ -52,7 +52,7 @@
 #' If not installed, the step will stop with a note about installing
 #' these packages.
 #'
-#' As with ordinary PCA, it is important to standardized the
+#' As with ordinary PCA, it is important to standardize the
 #'  variables prior to running PCA (`step_center` and
 #'  `step_scale` can be used for this purpose).
 #'
@@ -124,8 +124,8 @@ step_kpca <-
            skip = FALSE,
            id = rand_id("kpca")) {
 
-    recipes_pkg_check(c("dimRed", "kernlab"))
-    message(
+    recipes_pkg_check(required_pkgs.step_kpca())
+    rlang::inform(
       paste(
         "`step_kpca()` is deprecated in favor of either `step_kpca_rbf()`",
         "or `step_kpca_poly()`. It will be removed in future versions."
@@ -249,3 +249,10 @@ tidy.step_kpca <- function(x, ...) {
   res
 }
 
+
+
+#' @rdname required_pkgs.step
+#' @export
+required_pkgs.step_kpca <- function(x, ...) {
+  c("dimRed", "kernlab")
+}
