@@ -36,7 +36,7 @@
 #' @concept basis_expansion
 #' @export
 #' @details Kernel principal component analysis (kPCA) is an
-#'  extension a PCA analysis that conducts the calculations in a
+#'  extension of a PCA analysis that conducts the calculations in a
 #'  broader dimensionality defined by a kernel function. For
 #'  example, if a quadratic kernel function were used, each variable
 #'  would be represented by its original values as well as its
@@ -48,7 +48,7 @@
 #' If not installed, the step will stop with a note about installing
 #' these packages.
 #'
-#' As with ordinary PCA, it is important to standardized the
+#' As with ordinary PCA, it is important to standardize the
 #'  variables prior to running PCA (`step_center` and
 #'  `step_scale` can be used for this purpose).
 #'
@@ -112,7 +112,7 @@ step_kpca_rbf <-
            skip = FALSE,
            id = rand_id("kpca_rbf")) {
 
-    recipes_pkg_check(c("dimRed", "kernlab"))
+    recipes_pkg_check(required_pkgs.step_kpca_rbf())
 
     add_step(
       recipe,
@@ -255,3 +255,9 @@ tunable.step_kpca_rbf <- function(x, ...) {
     component_id = x$id
   )
 }
+
+#' @rdname required_pkgs.step
+#' @export
+required_pkgs.step_kpca_rbf <- function(x, ...) {
+  c("dimRed", "kernlab")
+}
