@@ -26,7 +26,7 @@
 #' `mixOmics::plsda()`, or `mixOmics::splsda()` (depending on the data and
 #' arguments).
 #' @param res A list of results are stored here once this preprocessing step
-#'  has be trained by [prep.recipe()].
+#'  has been trained by [prep.recipe()].
 #' @param prefix A character string that will be the prefix to the
 #'  resulting new variables. See notes below.
 #' @return An updated version of `recipe` with the new step
@@ -139,7 +139,7 @@ step_pls <-
       rlang::abort("`outcome` should select at least one column.")
     }
 
-    recipes_pkg_check("mixOmics")
+    recipes_pkg_check(required_pkgs.step_pls())
 
     add_step(
       recipe,
@@ -413,3 +413,10 @@ tunable.step_pls <- function(x, ...) {
     component_id = x$id
   )
 }
+
+
+#' @rdname required_pkgs.step
+#' @export
+required_pkgs.step_pls <- function(x, ...) {
+  c("mixOmics")
+}
