@@ -22,9 +22,9 @@
 #' @examples
 #' library(dplyr)
 #' recipe(~ ., data = iris) %>%
-#'   step_rename_at(everything(), fn = ~ gsub("\\.", "_", .)) %>%
+#'   step_rename_at(everything(), fn = ~ gsub(".", "_", ., fixed = TRUE)) %>%
 #'   prep() %>%
-#'   juice() %>%
+#'   bake(new_data = NULL) %>%
 #'   slice(1:10)
 #' @export
 step_rename_at <- function(
@@ -87,7 +87,7 @@ bake.step_rename_at <- function(object, new_data, ...) {
 print.step_rename_at <-
   function(x, width = max(20, options()$width - 35), ...) {
     cat("Variable renaming for ", sep = "")
-    printer(names(x$means), x$terms, x$trained, width = width)
+    printer(x$inputs, x$terms, x$trained, width = width)
     invisible(x)
   }
 
